@@ -20,7 +20,7 @@
 
 #include <QSignalMapper>
 
-#include <KLocale>
+#include <KLocalizedString>
 
 #include <core/course.h>
 #include <core/lesson.h>
