@@ -46,6 +46,7 @@ public:
         IndexRole,
         SourceRole
     };
+    Q_ENUM(AdditionalRoles)
     explicit ResourceModel( QObject* parent = 0);
     DataIndex* dataIndex() const;
     void setDataIndex(DataIndex* dataIndex);
@@ -53,6 +54,7 @@ public:
     QVariant data(const QModelIndex& index, int role) const;
     QVariant headerData(int section, Qt::Orientation orientation, int role) const;
     int rowCount(const QModelIndex &parent) const;
+    QHash<int, QByteArray> roleNames() const;
 
 signals:
     void dataIndexChanged();
